#########################################
Welcome to the Django hvad documentation!
#########################################

******************
About this project
******************

django-hvad provides a high level API to maintain multilingual content in your
database using the Django ORM.

Please note that this documentation assumes that you are familiar with
Django and Python, if you are not, please familiarize yourself with those first.

************************
Notes on Django versions
************************

The guideline is hvad supports all Django versions that are supported by the
Django team. This holds true for Long-Term Support releases as well. Support for
new versions will usually be introduced when they reach the beta stage.

Thus, django-hvad 1.5 is tested on the following configurations:

- Django 1.7.11, running Python 2.7, 3.3 or 3.4.
- Django 1.8.9, running Python 2.7, 3.3, 3.4 or 3.5.
- Django 1.9.2, running Python 2.7, 3.4 or 3.5.

All tests are run against MySQL and PostgreSQL.

***************
Contents
***************

.. toctree::
    :maxdepth: 3
    :titlesonly:
    :numbered: 2

    public/installation
    public/quickstart
    public/models
    public/queryset
    public/forms
    public/admin
    public/restframework
    public/faq
    public/release_notes
    public/contact
    public/contributing
    internal/index

    glossary
    

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
* :ref:`glossary`
